@@ -104,6 +104,7 @@ TRACKS = os.environ.get('GTRACKS_TRACKS',
 
 COORD_REGEX = re.compile(os.environ.get('GTRACKS_COORD_REGEX',
                                         '([Cc]hr)?[0-9XY]+:[0-9]+-[0-9]+$'))
+# ALT_COORD_REGEX = re.compile('[\s\S]+:[0-9]+-[0-9]+$')
 
 GENOME_TO_GENES = {
     'GRCh38': HG38_GENES_PATH, 'hg38': HG38_GENES_PATH,
@@ -222,8 +223,8 @@ def gtracks(region, output, tracks=TRACKS, genes: str = 'GRCh38',
 def parse_arguments():
     parser = argparse.ArgumentParser(
         description=(
-            'Plot bigWig signal tracks and gene annotations in a genomic '
-            'region'
+            'Plot bigWig, bedGraph, and BED signal tracks with gene annotations'
+            'in a genomic region'
         )
     )
     parser.add_argument(
